function auc = plot_PrR(TP, FP, TN, FN, ah, colors)

% auc = plot_PrR(TP, FP, TN, FN, [ah], [colors])
%
% Plots one or more precision recall curves and returns the AUC(s).
%
% ah -- optional axis handle to plot into
% colors -- optionally, colors for each graph can be specified
% returns the area under the precision-recall curve
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

assert(size(TP,1) == size(FP,1));
assert(size(TP,1) == size(TN,1));
assert(size(TP,1) == size(FN,1));
num_curves = size(TP,1);

if ~exist('colors', 'var'),
  c = colormap;
  colors = c(round(linspace(1,64,num_curves)),:);
end

hold on
for i=1:num_curves
  % Recall
  % add a tiny bit to denominator to avoid division by 0
  TPR = TP(i,:)./(TP(i,:)+FN(i,:) + 10^-6);
  % Precision
  % add a tiny bit to denominator to avoid division by 0
  TDR = TP(i,:)./(TP(i,:)+FP(i,:) + 10^-6);
  if exist('ah', 'var'),
    plot(ah, TPR, TDR, 'Color', colors(i,:), 'LineWidth', 2);
  else
    plot(TPR, TDR, 'Color', colors(i,:), 'LineWidth', 2);
  end
  
  % compute area under the curve
  TPR = TPR(end:-1:1);
  TDR = TDR(end:-1:1);
  assert(TPR(1)<0+10-5 & TPR(end)>1-10^-5);
  auc = area_trapz(TPR, TDR);
  if ~exist('ah', 'var'),
    th = text(0.1, 0.8-i*0.1, sprintf('AUC = %2.3f', auc));
    set(th, 'Color', colors(i,:));
  end
end
if exist('ah', 'var'),
  title(ah, 'Precision-recall curve');
  xlabel(ah, 'recall (sensitivity)');
  ylabel(ah, 'precision');
  axis(ah, [0 1 0 1]);
else
  title('Precision-recall curve');
  xlabel('recall (sensitivity)');
  ylabel('precision');
  axis([0 1 0 1]);
end