function array = reconstruct_array(fn_array, fn_suffix, PM_I_norm, probe_id, method_description)

% array = reconstruct_array(fn_array, fn_suffix, PM_I_norm, probe_id, ...
%                                   method_description)
%
% Reconstructs a .cel-like file from normalized intensities and writes a
% .cel like flat file.
%
% fn_array -- the file name of the original arrat whose intensity values
%   will be replaced by the normalized ones
% fn_suffix -- a file name suffix which will be appended to fn_array
% PM_I_norm -- a vector of normalized PM intensities
% probe_id -- genomic locations (chr*10^8+position) of probes
% returns an array struct similar to the one parsed from .cel files 
%   (see read_CEL, write_CEL)
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

map_dir = '../../PSB_data/maps/';
map = load([map_dir 'genomic_probes.mat'], ...
           'probe_id', 'probe_PM_array_idx');

load(fn_array);

assert(equal(map.probe_id, probe_id));
assert(all(size(PM_I_norm) == size(probe_id)));

array.data_type = method_description;
array.raw_mean = array.mean;
array.mean(map.probe_PM_array_idx) = PM_I_norm;

array.filename = [fn_array '_' fn_suffix];
save(array.filename, 'array');

write_CEL([array.filename '.CEL'], array);
