function [SVMs JOB_INFO] = model_sel_SVR(SVM, OPT, JOB_INFO)

% [SVMs JOB_INFO] = model_sel_SVR(SVM, OPT, JOB_INFO)
%
% Performs model selection for SVR submitting parallel cluster jobs if
% OPT.USE_RPROC==1.
%
% SVM -- a generic SVM struct which has fields specifying training data
%   and labels
% OPT -- a struct of settings (see main_training)
% JOB_INFO -- a job info struct for rpoc, can be empty but has to exist
%   if OPT.USE_RPROC==1
% returns a struct array containing SVM objects and a JOB_INFO object
%   if OPT.USE_RPROC==1
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

% constant parameters
SVM.PARAM.svm_eps       = OPT.SVR.PARAM.svm_eps;
SVM.PARAM.wdk_mismatch  = OPT.SVR.PARAM.wdk_mismatch;
SVM.PARAM.wdk_shift_vec = OPT.SVR.PARAM.wdk_shift_vec;
SVM.PARAM.cache_size    = OPT.SVR.PARAM.cache_size;

% grid search for model selection
for i=1:length(OPT.SVR.MOD_SEL_PARAM.C),
  SVM.PARAM.C         = OPT.SVR.MOD_SEL_PARAM.C(i);
  for j=1:length(OPT.SVR.MOD_SEL_PARAM.tube),
    SVM.PARAM.tube    = OPT.SVR.MOD_SEL_PARAM.tube(j);
    for k=1:length(OPT.SVR.MOD_SEL_PARAM.order),
      % for weighted degree kernel
      SVM.PARAM.order = OPT.SVR.MOD_SEL_PARAM.order(k);
      
      SVM.PARAM.fn_out = sprintf('%strained_svm_fold%i_quant%i_C%3.3f_tube%3.3f_o%i.mat', ...
                                 SVM.PARAM.out_dir, SVM.fold_id, SVM.quant_id, ...
                                 SVM.PARAM.C, SVM.PARAM.tube, SVM.PARAM.order);
      
      SVMs(SVM.quant_id) = SVM;

      fprintf('Training SVM for %ith quantile, intensity range [%2.3f, %2.3f]...\n', ...
              SVM.quant_id, SVM.I_min, SVM.I_max);
      
      if OPT.USE_RPROC,
        assert(exist('JOB_INFO')==1);
        
        % RPROC settings
        RPROC_MEMREQ             = 2700;
        RPROC_OPT.express        = 0;
        RPROC_OPT.immediately_bg = 0;
        RPROC_OPT.immediately    = 0;
        RPROC_OPT.arch           = 64; % take only 64 bit nodes
        RPROC_OPT.identifier     = sprintf('TAtrSVRp%i_C%3.3f_tube%3.3f_o%i_', ...
                                           SVM.quant_id, SVM.PARAM.C, SVM.PARAM.tube, ...
                                           SVM.PARAM.order);
        RPROC_TIME               = 8*60; % mins
        
        JOB_INFO{end+1} = rproc('train_SVR', ...
                                SVM, RPROC_MEMREQ, RPROC_OPT, RPROC_TIME);
        fprintf('\nSubmitted job %i\n\n', length(JOB_INFO));
      else
        train_SVR(SVM);
      end
    end
  end
end
