function fh = plot_pos_quantile(I, nucl_idx, PROBE_LEN, k_percentile, tag)

% fh = plot_pos_quantile(I, nucl_idx, PROBE_LEN, k_percentile, tag)
%
% Creates sequence quantile plots as proposed in T.E. Royce et al,
% Assessing the need for sequence-based normalization in tiling
% microarray experiments, Bioinformatics (2007).
%
% I -- an intensity vector
% nucl_idx -- an index struct specifying probe substrings 
%   (see seq_quantile_norm.m)
% PROBE_LEN -- length of the oligonucleotide probes
% k_percentile -- the desired percentile to be plotted
% tag -- a tag string for intensity legends
% returns a figure handle with the quantile plot
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

perc_I = struct;
acgt = 'ACGT';
for j=1:length(acgt),
  perc_I = setfield(perc_I, acgt(j), zeros(1,PROBE_LEN));
end
for i=1:PROBE_LEN,
  for j=1:length(acgt),
    I_tmp = I(getfield(nucl_idx, {i}, acgt(j)));
    I_tmp = I_tmp(~isnan(I_tmp));
    
    p = getfield(perc_I, acgt(j));
    p(i) = percentile(I_tmp, k_percentile);
    perc_I = setfield(perc_I, acgt(j), p);
  end
end

figure
style = 'o-';
hold on
colors = [ 25  50 135;
          175  30  25;
          250 200   0;
           45  95  30]/256;
for j=1:length(acgt),
  plot(1:PROBE_LEN, getfield(perc_I, acgt(j)), style, 'Color', colors(j,:));
end
if ~exist('tag', 'var'),
  legend('A (raw)', 'C (raw)', 'G (raw)', 'T (raw)', ...
         'Location', 'NorthEastOutside');
  tag = '';
else
  legend(['A (' tag ')'], ['C (' tag ')'], ...
         ['G (' tag ')'], ['T (' tag ')'], ...
         'Location', 'NorthEastOutside');
end  
axis([0 25 6 12]) 
xlabel('Nucleotide position');
ylabel(sprintf('Log_2 intensity %ith percentile',k_percentile));
title(sprintf('Sequence-dependance of PM intensity %ith percentile',k_percentile));

fh = gcf;
