function [predictor_idx I_boundaries] = split_data(I, num_predictors)

% [predictor_idx I_boundaries] = split_data(I, num_predictors)
%
% Determines intensity quantiles and assigns the corresponding predictor
% to each intensity value.
%
% I -- a vector of hybridisation intensities
% num_predictors -- the desired number of quantiles (i.e. the number of
%   predictors)
% returns an index of the same size as I with values out of
%   {1,...,num_predictors}, additionally returns the quantiles as
%   interval boundaries of each predictor
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

predictor_idx = zeros(1,length(I));
  
% assumes that I does NOT contain NaN
assert(~any(isnan(I)));
I_sorted = sort(I);

I_boundaries = zeros(1,num_predictors);
for i=1:num_predictors,
  last_elem = round(i*length(I)/num_predictors);
  I_boundaries(i+1) = I_sorted(last_elem);
  idx = find(I_boundaries(i)<I & I<=I_boundaries(i+1));
  predictor_idx(idx) = i;
end
assert(all(predictor_idx>0 & predictor_idx<=num_predictors));

%hist(predictor_idx, num_predictors);
  
