function SVM = train_SVR(SVM);

% SVM = train_SVR(SVM);
%
% Does the actual SVR training using the Shogun toolbox.
% (see http://www.shogun-toolbox.org/)
%
% SVM -- a SVM struct which has fields specifying training data, labels
%   and hyperparameter values
% returns a SVM struct augmented by alphas and b as well as training
%   errors 
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

set_paths

disp(SVM);
disp(SVM.PARAM);

sg('send_command', 'new_svm SVRLIGHT');
sg('send_command', 'use_linadd 1') ;
%sg('send_command', 'loglevel ALL');
sg('send_command', 'use_precompute 0');


sg('send_command','clean_features TRAIN') ;
sg('add_features','TRAIN', SVM.X_train_1, 'DNA');
sg('add_features','TRAIN', SVM.X_train_2);
sg('send_command', sprintf('set_kernel COMBINED %d', SVM.PARAM.cache_size));
sg('send_command', sprintf('add_kernel 1 WEIGHTEDDEGREEPOS3 CHAR 10 %i %i %i 1 %s', ...
                           SVM.PARAM.order, SVM.PARAM.wdk_mismatch, size(SVM.X_train_1,1), ...
                           sprintf('%i ', SVM.PARAM.wdk_shift_vec)));
sg('send_command', sprintf('add_kernel 1 LINEAR REAL 10'));

sg('set_labels', 'TRAIN', SVM.Y_train);
sg('send_command', 'init_kernel TRAIN');

sg('send_command', sprintf('c %f', SVM.PARAM.C));
sg('send_command', sprintf('svm_epsilon %f', SVM.PARAM.svm_eps));
sg('send_command', sprintf('svr_tube_epsilon %f', SVM.PARAM.tube));

tic;
fprintf('\nstarted SVM training: %s\n\n', datestr(now,'yyyy-mm-dd_HHhMM'));
sg('send_command', 'svm_train');
fprintf('\n');
toc
fprintf('finished SVM training: %s\n\n', datestr(now,'yyyy-mm-dd_HHhMM'));
[SVM.b, SVM.alphas] = sg('get_svm');

% training error
sg('send_command','clean_features TEST');
sg('add_features','TEST', SVM.X_train_1, 'DNA');
sg('add_features','TEST', SVM.X_train_2);
sg('send_command', 'init_kernel TEST');

Y_pred = sg('svm_classify');

SVM.Q1_TR = mean(abs(Y_pred - SVM.Y_train)) ...
    / mean(abs(SVM.Y_train - median(SVM.Y_train)));
SVM.Q2_TR = mean((Y_pred - SVM.Y_train).^2) ...
    / mean((SVM.Y_train - mean(SVM.Y_train)).^2);

disp(SVM);
save(SVM.PARAM.fn_out, 'SVM');

