function [genes] = intensities_to_genes(I, genes, fieldname, LABEL)

% [genes] = intensities_to_genes(I, genes, fieldname, LABEL)
%
% Augments a gene structure by hybridization intensities
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

fprintf('Adding intensities to genes...\n');

for g=1:length(genes),
  probe_idx = genes(g).probes(:,2);
  genes(g).hyb = setfield(genes(g).hyb, fieldname, I(probe_idx)');
  if isfield(genes(g).hyb, [fieldname '_transcript']),
    genes(g).hyb = rmfield(genes(g).hyb, [fieldname '_transcript']);
  end
  
  if isfield(genes, 'exons'), % miRNA genes do not have annotated exons
    for i=1:length(genes(g).transcripts)
      exon_idx   = find(genes(g).probes_exonic(:,i)>0);
      intron_idx = find(genes(g).probes_intronic(:,i)>0);
      
      % convert into global indices
      exon_idx   = probe_idx(exon_idx);
      intron_idx = probe_idx(intron_idx);
      
      % I_mean in exons will be the mean of the exon probes, 
      % or NaN if all exon probes have NaN intensities
      I_mean = I(exon_idx);
      I_mean = I_mean(~isnan(I_mean));
      if ~isempty(I_mean),
        I_mean = mean(I_mean);
        if isfield(genes(g).hyb, [fieldname '_transcript']),
          tmp = getfield(genes(g).hyb, [fieldname '_transcript']);
          tmp = [tmp I_mean];
          genes(g).hyb = setfield(genes(g).hyb, [fieldname '_transcript'], tmp);
        else
          genes(g).hyb = setfield(genes(g).hyb, [fieldname '_transcript'], I_mean);
        end
      else
        genes(g).hyb = setfield(genes(g).hyb, [fieldname '_transcript'], nan);
      end
    end
  end
  if mod(g,100)==0, fprintf('  %i\r',g); end
end
fprintf('\n');



